@@ -14,10 +14,16 @@ track_merge <- function(type = c(
   "grunnkrets"
 ),
 from = NULL,
-to = NULL) {
+to = NULL,
+names = TRUE) {
   type <- match.arg(type)
   dt <- track_change(type, from, to)
   data.table::setkey(dt, currentCode, changeOccurred)
   dt[!is.na(currentCode), merge := .N, by = data.table::rleid(changeOccurred, currentCode)]
   out <- dt[merge > 1]
+
+  if (!names)
+    out[, (granularityNames) := NULL]
+
+  return(out)
 }
