@@ -5,7 +5,7 @@ test_that("get code at", {
 
 test_that("get codes - all", {
   vcr::use_cassette("codes-fromto", {
-    dt <- get_code(type = "fylke", from = 2018, to = 2020)
+    dt <- get_code(type = "fylke", from = 2016, to = 2018, names = F)
   })
 
   expect_equal(dt, outDT)
