@@ -1,7 +1,7 @@
 
 test_that("get correspond - all", {
   vcr::use_cassette("correspond", {
-    dt <- get_correspond(type = "fylke", correspond = "kommune", from = 2018, to = 2020)
+    dt <- get_correspond(type = "fylke", correspond = "kommune", from = 2016, to = 2018, names = F)
   })
 
   expect_equal(dt, dtCorr)
